@@ -9,7 +9,7 @@
 
 //! Utility functions for bit manipulation operations
 
-use std::fmt;
+use core::fmt;
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub enum Endianness {
@@ -382,12 +382,10 @@ pub fn operations(offset: usize, size: usize) -> Option<Vec<GetOperation>> {
         return None;
     }
 
-    let num_full_bytes = size / 8;
-    let num_bytes = if offset > 0 || size % 8 != 0 {
-        num_full_bytes + 1
-    } else {
-        num_full_bytes
-    };
+
+    let start = offset / 8;
+    let end = (offset+size-1) / 8;
+    let num_bytes = (end - start) + 1;
 
     let mut current_offset = offset;
     let mut num_bits_remaining = size;
@@ -627,6 +625,22 @@ fn operations_test() {
             }
         ]
     );
+
+    assert_eq!(
+        operations(6, 6).unwrap(),
+        vec![
+            Op {
+                mask: 3,
+                shiftl: 4,
+                shiftr: 0,
+            },
+            Op {
+                mask: 240,
+                shiftl: 0,
+                shiftr: 4,
+            }
+        ]
+    );
 }
 
 /// Mask `bits` bits of a byte. eg. mask_high_bits(2) == 0b00000011
